OSDN Git Service

* ChangeLog: Fix typos.
authorkazu <kazu>
Sun, 30 Nov 2003 18:40:41 +0000 (18:40 +0000)
committerkazu <kazu>
Sun, 30 Nov 2003 18:40:41 +0000 (18:40 +0000)
* ecoff.c: Fix comment typos.
* ecofflink.c: Likewise.
* format.c: Likewise.
* hp300hpux.c: Likewise.
* i386linux.c: Likewise.
* ieee.c: Likewise.
* m68klinux.c: Likewise.
* mach-o.h: Likewise.
* mipsbsd.c: Likewise.
* oasys.c: Likewise.
* opncls.c: Likewise.
* peXXigen.c: Likewise.
* reloc.c: Likewise.
* reloc16.c: Likewise.
* section.c: Likewise.
* simple.c: Likewise.
* som.c: Likewise.
* som.h: Likewise.
* sparclinux.c: Likewise.
* srec.c: Likewise.
* syms.c: Likewise.
* targets.c: Likewise.
* tekhex.c: Likewise.
* versados.c: Likewise.
* vms-gsd.c: Likewise.
* vms-hdr.c: Likewise.
* vms-misc.c: Likewise.
* xcofflink.c: Likewise.
* xsym.h: Likewise.
* bfd-in2.h: Regenerate.

31 files changed:
bfd/ChangeLog
bfd/bfd-in2.h
bfd/ecoff.c
bfd/ecofflink.c
bfd/format.c
bfd/hp300hpux.c
bfd/i386linux.c
bfd/ieee.c
bfd/m68klinux.c
bfd/mach-o.h
bfd/mipsbsd.c
bfd/oasys.c
bfd/opncls.c
bfd/peXXigen.c
bfd/reloc.c
bfd/reloc16.c
bfd/section.c
bfd/simple.c
bfd/som.c
bfd/som.h
bfd/sparclinux.c
bfd/srec.c
bfd/syms.c
bfd/targets.c
bfd/tekhex.c
bfd/versados.c
bfd/vms-gsd.c
bfd/vms-hdr.c
bfd/vms-misc.c
bfd/xcofflink.c
bfd/xsym.h

index bb69c7f..a5d422e 100644 (file)
 
 2003-05-04  H.J. Lu <hjl@gnu.org>
 
-       * elflink.h (elf_merge_symbol): Correctly handle weak definiton.
+       * elflink.h (elf_merge_symbol): Correctly handle weak definition.
 
 2003-05-04  H.J. Lu <hjl@gnu.org>
 
        * config.bfd: Added DLX configuraton.
        * Makefile.am: Added DLX configuraton.
        * configure.in: Added DLX configuraton.
-       * archures.c: Add DLX architecure.
+       * archures.c: Add DLX architecture.
        * reloc.c: Add DLX relocs.
        * targets.c: Added DLX target vector.
        * configure: Regenerate.
index d7c8a81..6c2d299 100644 (file)
@@ -1932,7 +1932,7 @@ struct reloc_howto_struct
 
   /* If this field is non null, then the supplied function is
      called rather than the normal function.  This allows really
-     strange relocation methods to be accomodated (e.g., i960 callj
+     strange relocation methods to be accommodated (e.g., i960 callj
      instructions).  */
   bfd_reloc_status_type (*special_function)
     (bfd *, arelent *, struct bfd_symbol *, void *, asection *,
@@ -2551,7 +2551,7 @@ in the instruction.  */
 /* IBM 370/390 relocations  */
   BFD_RELOC_I370_D12,
 
-/* The type of reloc used to build a contructor table - at the moment
+/* The type of reloc used to build a constructor table - at the moment
 probably a 32 bit wide absolute relocation, but the target can choose.
 It generally does map to one of the other relocation types.  */
   BFD_RELOC_CTOR,
@@ -2848,11 +2848,11 @@ data area pointer.  */
   BFD_RELOC_V850_TDA_4_4_OFFSET,
 
 /* This is a 16 bit offset from the short data area pointer, with the
-bits placed non-contigously in the instruction.  */
+bits placed non-contiguously in the instruction.  */
   BFD_RELOC_V850_SDA_16_16_SPLIT_OFFSET,
 
 /* This is a 16 bit offset from the zero data area pointer, with the
-bits placed non-contigously in the instruction.  */
+bits placed non-contiguously in the instruction.  */
   BFD_RELOC_V850_ZDA_16_16_SPLIT_OFFSET,
 
 /* This is a 6 bit offset from the call table base pointer.  */
@@ -3209,7 +3209,7 @@ that are not used, so that the code for those functions need not be
 included in the output.
 
 VTABLE_INHERIT is a zero-space relocation used to describe to the
-linker the inheritence tree of a C++ virtual function table.  The
+linker the inheritance tree of a C++ virtual function table.  The
 relocation's symbol should be the parent class' vtable, and the
 relocation should be located at the child vtable.
 
@@ -3318,7 +3318,7 @@ This is the 3 bit of a value.  */
 /* Motorola 68HC11 reloc.
 This reloc marks the beginning of a jump/call instruction.
 It is used for linker relaxation to correctly identify beginning
-of instruction and change some branchs to use PC-relative
+of instruction and change some branches to use PC-relative
 addressing mode.  */
   BFD_RELOC_M68HC11_RL_JUMP,
 
@@ -3530,7 +3530,7 @@ typedef struct bfd_symbol
      <<BSF_LOCAL>>, <<BSF_FORT_COMM>>,  <<BSF_UNDEFINED>> or
      <<BSF_GLOBAL>>.  */
 
-  /* The symbol is a debugging record. The value has an arbitary
+  /* The symbol is a debugging record. The value has an arbitrary
      meaning, unless BSF_DEBUGGING_RELOC is also set.  */
 #define BSF_DEBUGGING  0x08
 
index b45f168..b9b1861 100644 (file)
@@ -4129,7 +4129,7 @@ _bfd_ecoff_bfd_final_link (abfd, info)
 
       if (bfd_get_flavour (input_bfd) == bfd_target_ecoff_flavour)
        {
-         /* Abitrarily set the symbolic header vstamp to the vstamp
+         /* Arbitrarily set the symbolic header vstamp to the vstamp
             of the first object file in the link.  */
          if (symhdr->vstamp == 0)
            symhdr->vstamp
index 89edae3..9e23848 100644 (file)
@@ -2007,7 +2007,7 @@ lookup_line (abfd, debug_info, debug_swap, line_info)
   /* eraxxon: 'fdrtab_lookup' doesn't give what we want, at least for Compaq's
      C++ compiler 6.2.  Consider three FDRs with starting addresses of x, y,
      and z, respectively, such that x < y < z.  Assume further that
-     y < 'offset' < z.  It is possble at times that the PDR for 'offset' is
+     y < 'offset' < z.  It is possible at times that the PDR for 'offset' is
      associated with FDR x and *not* with FDR y.  Erg!!
 
      From a binary dump of my C++ test case 'moo' using Compaq's coffobjanl
@@ -2030,7 +2030,7 @@ lookup_line (abfd, debug_info, debug_swap, line_info)
 
      Since the FDRs that are causing so much havok (in this case) 1) do not
      describe actual files (fdr.rss == -1), and 2) contain only compiler
-     genarated routines, I thought a simple fix would be to exclude them from
+     generated routines, I thought a simple fix would be to exclude them from
      the FDR table in 'mk_fdrtab'.  But, besides not knowing for certain
      whether this would be correct, it creates an additional problem.  If we
      happen to ask for source file info on a compiler generated (procedure)
index 256ec0e..9d9ee86 100644 (file)
@@ -425,7 +425,7 @@ bfd_format_string (bfd_format format)
   switch (format)
     {
     case bfd_object:
-      return "object";         /* Linker/assember/compiler output.  */
+      return "object";         /* Linker/assembler/compiler output.  */
     case bfd_archive:
       return "archive";                /* Object archive file.  */
     case bfd_core:
index e5a567d..f6cdd19 100644 (file)
@@ -475,7 +475,7 @@ NAME (aout,swap_exec_header_in) (abfd, raw_bytes, execp)
 
   /***************************************************************/
   /* check the header to see if it was generated by a bfd output */
-  /* this is detected rather bizarely by requiring a bunch of    */
+  /* this is detected rather bizarrely by requiring a bunch of   */
   /* header fields to be zero and an old unused field (now used) */
   /* to be set.                                                  */
   /***************************************************************/
@@ -588,7 +588,7 @@ MY (slurp_symbol_table) (abfd)
      assignment to the strings pointer is done after we're thru using
      the nlist so we don't overwrite anything important. */
 
-  /* OK, now walk the new symtable, cacheing symbol properties */
+  /* OK, now walk the new symtable, caching symbol properties */
   {
     aout_symbol_type *cache_ptr = cached;
     aout_symbol_type cache_save;
@@ -611,7 +611,7 @@ MY (slurp_symbol_table) (abfd)
          return FALSE;
 
        /********************************************************/
-       /* for hpux, the 'lenght' value indicates the length of */
+       /* for hpux, the 'length' value indicates the length of */
        /* the symbol name which follows the nlist entry.       */
        /********************************************************/
        if (length)
index 84ae477..da36e75 100644 (file)
@@ -112,7 +112,7 @@ i386linux_write_object_contents (abfd)
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
index f8af3f5..8a08028 100644 (file)
@@ -1043,7 +1043,7 @@ ieee_slurp_external_symbols (abfd)
            (void) must_parse_int (&(ieee->h));
            /* Fetch the default size if not resolved.  */
            size = must_parse_int (&(ieee->h));
-           /* Fetch the defautlt value if available.  */
+           /* Fetch the default value if available.  */
            if (! parse_int (&(ieee->h), &value))
              {
                value = 0;
@@ -1639,7 +1639,7 @@ ieee_object_p (abfd)
     const bfd_arch_info_type *arch;
     char family[10];
 
-    /* IEEE does not specify the format of the processor identificaton
+    /* IEEE does not specify the format of the processor identification
        string, so the compiler is free to put in it whatever it wants.
        We try here to recognize different processors belonging to the
        m68k family.  Code for other processors can be added here.  */
index 90f342c..996e516 100644 (file)
@@ -113,7 +113,7 @@ m68klinux_write_object_contents (abfd)
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
index c94f01d..1f7dd60 100644 (file)
@@ -74,11 +74,11 @@ typedef enum bfd_mach_o_load_command_type
     BFD_MACH_O_LC_FVMFILE = 0x9,       /* Fixed VM file inclusion.  */
     BFD_MACH_O_LC_PREPAGE = 0xa,       /* Prepage command (internal use).  */
     BFD_MACH_O_LC_DYSYMTAB = 0xb,      /* Dynamic link-edit symbol table info.  */
-    BFD_MACH_O_LC_LOAD_DYLIB = 0xc,    /* Load a dynamicly linked shared library.  */
-    BFD_MACH_O_LC_ID_DYLIB = 0xd,      /* Dynamicly linked shared lib identification.  */
+    BFD_MACH_O_LC_LOAD_DYLIB = 0xc,    /* Load a dynamically linked shared library.  */
+    BFD_MACH_O_LC_ID_DYLIB = 0xd,      /* Dynamically linked shared lib identification.  */
     BFD_MACH_O_LC_LOAD_DYLINKER = 0xe, /* Load a dynamic linker.  */
     BFD_MACH_O_LC_ID_DYLINKER = 0xf,   /* Dynamic linker identification.  */
-    BFD_MACH_O_LC_PREBOUND_DYLIB = 0x10,/* Modules prebound for a dynamicly.  */
+    BFD_MACH_O_LC_PREBOUND_DYLIB = 0x10,/* Modules prebound for a dynamically.  */
     BFD_MACH_O_LC_ROUTINES = 0x11,     /* Image routines.  */
     BFD_MACH_O_LC_SUB_FRAMEWORK = 0x12,        /* Sub framework.  */
     BFD_MACH_O_LC_SUB_UMBRELLA = 0x13, /* Sub umbrella.  */
@@ -86,7 +86,7 @@ typedef enum bfd_mach_o_load_command_type
     BFD_MACH_O_LC_SUB_LIBRARY = 0x15,   /* Sub library.  */
     BFD_MACH_O_LC_TWOLEVEL_HINTS = 0x16,/* Two-level namespace lookup hints.  */
     BFD_MACH_O_LC_PREBIND_CKSUM = 0x17, /* Prebind checksum.  */
-    /* Load a dynamicly linked shared library that is allowed to be
+    /* Load a dynamically linked shared library that is allowed to be
        missing (weak).  */
     BFD_MACH_O_LC_LOAD_WEAK_DYLIB = 0x18
   }
@@ -231,7 +231,7 @@ typedef struct bfd_mach_o_symtab_command
 bfd_mach_o_symtab_command;
 
 /* This is the second set of the symbolic information which is used to support
-   the data structures for the dynamicly link editor.
+   the data structures for the dynamically link editor.
 
    The original set of symbolic information in the symtab_command which contains
    the symbol and string tables must also be present when this load command is
@@ -250,7 +250,7 @@ bfd_mach_o_symtab_command;
        reference symbol table
        indirect symbol table
    The first three tables above (the table of contents, module table and
-   reference symbol table) are only present if the file is a dynamicly linked
+   reference symbol table) are only present if the file is a dynamically linked
    shared library.  For executable and object modules, which are files
    containing only one module, the information that would be in these three
    tables is determined as follows:
@@ -259,7 +259,7 @@ bfd_mach_o_symtab_command;
                       file is part of the module.
        reference symbol table - is the defined and undefined external symbols
 
-   For dynamicly linked shared library files this load command also contains
+   For dynamically linked shared library files this load command also contains
    offsets and sizes to the pool of relocation entries for all sections
    separated into two groups:
        external relocation entries
@@ -281,7 +281,7 @@ typedef struct bfd_mach_o_dysymtab_command
 
      The last two groups are used by the dynamic binding process to do the
      binding (indirectly through the module table and the reference symbol
-     table when this is a dynamicly linked shared library file).  */
+     table when this is a dynamically linked shared library file).  */
 
   unsigned long ilocalsym;    /* Index to local symbols.  */
   unsigned long nlocalsym;    /* Number of local symbols.  */
@@ -293,7 +293,7 @@ typedef struct bfd_mach_o_dysymtab_command
   /* For the for the dynamic binding process to find which module a symbol
      is defined in the table of contents is used (analogous to the ranlib
      structure in an archive) which maps defined external symbols to modules
-     they are defined in.  This exists only in a dynamicly linked shared
+     they are defined in.  This exists only in a dynamically linked shared
      library file.  For executable and object modules the defined external
      symbols are sorted by name and is use as the table of contents.  */
 
@@ -304,7 +304,7 @@ typedef struct bfd_mach_o_dysymtab_command
      table must reflect the modules that the file was created from.  This is
      done by having a module table that has indexes and counts into the merged
      tables for each module.  The module structure that these two entries
-     refer to is described below.  This exists only in a dynamicly linked
+     refer to is described below.  This exists only in a dynamically linked
      shared library file.  For executable and object modules the file only
      contains one module so everything in the file belongs to the module.  */
 
@@ -315,7 +315,7 @@ typedef struct bfd_mach_o_dysymtab_command
      indicates the external references (defined and undefined) each module
      makes.  For each module there is an offset and a count into the
      reference symbol table for the symbols that the module references.
-     This exists only in a dynamicly linked shared library file.  For
+     This exists only in a dynamically linked shared library file.  For
      executable and object modules the defined external symbols and the
      undefined external symbols indicates the external references.  */
 
@@ -363,7 +363,7 @@ typedef struct bfd_mach_o_dysymtab_command
 
   /* All the local relocation entries are grouped together (they are not
      grouped by their module since they are only used if the object is moved
-     from it staticly link edited address).  */
+     from it statically link edited address).  */
 
   unsigned long locreloff;    /* Offset to local relocation entries.  */
   unsigned long nlocrel;      /* Number of local relocation entries.  */
index 59f231b..cb2050f 100644 (file)
@@ -220,7 +220,7 @@ mips_fix_jmp_addr (abfd, reloc_entry, symbol, data, input_section, output_bfd,
       && (symbol->flags & BSF_WEAK) == 0)
     return bfd_reloc_undefined;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
   if (bfd_is_com_section (symbol->section))
     relocation = 0;
@@ -271,7 +271,7 @@ mips_fix_hi16_s (abfd, reloc_entry, symbol, data, input_section,
       && (symbol->flags & BSF_WEAK) == 0)
     return bfd_reloc_undefined;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
   if (bfd_is_com_section (symbol->section))
     relocation = 0;
index 8c30197..be6a8d9 100644 (file)
@@ -324,7 +324,7 @@ oasys_archive_p (abfd)
 
   /*
     There isn't a magic number in an Oasys archive, so the best we
-    can do to verify reasnableness is to make sure that the values in
+    can do to verify reasonableness is to make sure that the values in
     the header are too weird
     */
 
index 34b39ae..96f1e14 100644 (file)
@@ -201,7 +201,7 @@ DESCRIPTION
        descriptors for other opens), with the supplied @var{fd} used as
        an initial file descriptor (but subject to closure at any time),
        call bfd_set_cacheable(bfd, 1) on the returned BFD.  The default
-       is to assume no cacheing; the file descriptor will remain open
+       is to assume no caching; the file descriptor will remain open
        until <<bfd_close>>, and will not be affected by BFD operations
        on other files.
 
index f3b3a96..df71a80 100644 (file)
@@ -645,7 +645,7 @@ _bfd_XXi_swap_aouthdr_out (abfd, in, out)
 
   if (extra->DataDirectory[1].VirtualAddress == 0)
     /* Until other .idata fixes are made (pending patch), the entry for
-       .idata is needed for backwards compatability.  FIXME.  */
+       .idata is needed for backwards compatibility.  FIXME.  */
     add_data_entry (abfd, extra, 1, ".idata", ib);
     
   /* For some reason, the virtual size (which is what's set by
@@ -969,7 +969,7 @@ _bfd_XXi_swap_scnhdr_out (abfd, in, out)
       && strcmp (scnhdr_int->s_name, ".text") == 0)
     {
       /* By inference from looking at MS output, the 32 bit field
-        which is the combintion of the number_of_relocs and
+        which is the combination of the number_of_relocs and
         number_of_linenos is used for the line number count in
         executables.  A 16-bit field won't do for cc1.  The MS
         document says that the number of relocs is zero for
index 8fdca41..ad4963f 100644 (file)
@@ -319,7 +319,7 @@ CODE_FRAGMENT
 .
 .  {* If this field is non null, then the supplied function is
 .     called rather than the normal function.  This allows really
-.     strange relocation methods to be accomodated (e.g., i960 callj
+.     strange relocation methods to be accommodated (e.g., i960 callj
 .     instructions).  *}
 .  bfd_reloc_status_type (*special_function)
 .    (bfd *, arelent *, struct bfd_symbol *, void *, asection *,
@@ -627,7 +627,7 @@ bfd_perform_relocation (bfd *abfd,
                              / bfd_octets_per_byte (abfd)))
     return bfd_reloc_outofrange;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
 
   /* Get symbol value.  (Common symbols are special.)  */
@@ -1017,7 +1017,7 @@ bfd_install_relocation (bfd *abfd,
                              / bfd_octets_per_byte (abfd)))
     return bfd_reloc_outofrange;
 
-  /* Work out which section the relocation is targetted at and the
+  /* Work out which section the relocation is targeted at and the
      initial relocation command value.  */
 
   /* Get symbol value.  (Common symbols are special.)  */
@@ -2507,7 +2507,7 @@ ENUMDOC
 ENUM
   BFD_RELOC_CTOR
 ENUMDOC
-  The type of reloc used to build a contructor table - at the moment
+  The type of reloc used to build a constructor table - at the moment
   probably a 32 bit wide absolute relocation, but the target can choose.
   It generally does map to one of the other relocation types.
 
@@ -2971,12 +2971,12 @@ ENUM
   BFD_RELOC_V850_SDA_16_16_SPLIT_OFFSET
 ENUMDOC
   This is a 16 bit offset from the short data area pointer, with the
-  bits placed non-contigously in the instruction.
+  bits placed non-contiguously in the instruction.
 ENUM
   BFD_RELOC_V850_ZDA_16_16_SPLIT_OFFSET
 ENUMDOC
   This is a 16 bit offset from the zero data area pointer, with the
-  bits placed non-contigously in the instruction.
+  bits placed non-contiguously in the instruction.
 ENUM
   BFD_RELOC_V850_CALLT_6_7_OFFSET
 ENUMDOC
@@ -3482,7 +3482,7 @@ ENUMDOC
   included in the output.
 
   VTABLE_INHERIT is a zero-space relocation used to describe to the
-  linker the inheritence tree of a C++ virtual function table.  The
+  linker the inheritance tree of a C++ virtual function table.  The
   relocation's symbol should be the parent class' vtable, and the
   relocation should be located at the child vtable.
 
@@ -3675,7 +3675,7 @@ ENUMDOC
   Motorola 68HC11 reloc.
   This reloc marks the beginning of a jump/call instruction.
   It is used for linker relaxation to correctly identify beginning
-  of instruction and change some branchs to use PC-relative
+  of instruction and change some branches to use PC-relative
   addressing mode.
 ENUM
   BFD_RELOC_M68HC11_RL_GROUP
index 3a4c3d3..720e2d6 100644 (file)
@@ -193,7 +193,7 @@ bfd_coff_reloc16_relax_section (abfd, input_section, link_info, again)
       bfd_size_type amt;
 
       /* Allocate and initialize the shrinks array for this section.
-        The last element is used as an accumlator of shrinks.  */
+        The last element is used as an accumulator of shrinks.  */
       amt = reloc_count + 1;
       amt *= sizeof (unsigned);
       shrinks = (unsigned *) bfd_zmalloc (amt);
index e99062a..752d033 100644 (file)
@@ -1065,7 +1065,7 @@ DESCRIPTION
 
 |      func (abfd, the_section, obj);
 
-       This is the prefered method for iterating over sections; an
+       This is the preferred method for iterating over sections; an
        alternative would be to use a loop:
 
 |         section *p;
index afed604..4b597a4 100644 (file)
@@ -211,7 +211,7 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
 
   /* The sections in ABFD may already have output sections and offsets set.
      Because this function is primarily for debug sections, and GCC uses the
-     knowledge that debug sections will generally have VMA 0 when emiting
+     knowledge that debug sections will generally have VMA 0 when emitting
      relocations between DWARF-2 sections (which are supposed to be
      section-relative offsets anyway), we need to reset the output offsets
      to zero.  We also need to arrange for section->output_section->vma plus
index e8cf8ca..9066257 100644 (file)
--- a/bfd/som.c
+++ b/bfd/som.c
@@ -1715,7 +1715,7 @@ hppa_som_gen_reloc_type (abfd, base_type, format, field, sym_diff, sym)
 #ifndef NO_PCREL_MODES
        /* If we have short and long pcrel modes, then generate the proper
           mode selector, then the pcrel relocation.  Redundant selectors
-          will be eliminted as the relocs are sized and emitted.  */
+          will be eliminated as the relocs are sized and emitted.  */
        bfd_size_type amt = sizeof (int);
        final_types[0] = (int *) bfd_alloc (abfd, amt);
        if (!final_types[0])
@@ -2480,7 +2480,7 @@ som_is_subspace (section)
   return TRUE;
 }
 
-/* Return TRUE if the given space containins the given subspace.  It
+/* Return TRUE if the given space contains the given subspace.  It
    is safe to assume space really is a space, and subspace really
    is a subspace.  */
 
@@ -2734,7 +2734,7 @@ som_write_fixups (abfd, current_offset, total_reloc_sizep)
            continue;
 
          /* If this subspace does not have real data, then we are
-            finised with it.  */
+            finished with it.  */
          if ((subsection->flags & SEC_HAS_CONTENTS) == 0)
            {
              som_section_data (subsection)->subspace_dict->fixup_request_index
@@ -3200,7 +3200,7 @@ som_write_symbol_strings (abfd, current_offset, syms, num_syms, string_sizep,
   /* This gets a bit gruesome because of the compilation unit.  The
      strings within the compilation unit are part of the symbol
      strings, but don't have symbol_dictionary entries.  So, manually
-     write them and update the compliation unit header.  On input, the
+     write them and update the compilation unit header.  On input, the
      compilation unit header contains local copies of the strings.
      Move them aside.  */
   if (compilation_unit)
@@ -3906,7 +3906,7 @@ som_finish_writing (abfd)
       section = section->next;
     }
 
-  /* All the subspace dictiondary records are written, and all the
+  /* All the subspace dictionary records are written, and all the
      fields are set up in the space dictionary records.
 
      Seek to the right location and start writing the space
@@ -3978,7 +3978,7 @@ som_finish_writing (abfd)
       exec_header->exec_flags = obj_som_exec_data (abfd)->exec_flags;
 
       /* Oh joys.  Ram some of the BSS data into the DATA section
-        to be compatable with how the hp linker makes objects
+        to be compatible with how the hp linker makes objects
         (saves memory space).  */
       tmp = exec_header->exec_dsize;
       tmp = SOM_ALIGN (tmp, PA_PAGESIZE);
@@ -5780,7 +5780,7 @@ som_slurp_armap (abfd)
                       + sizeof (struct lst_header)), SEEK_SET) != 0)
     return FALSE;
 
-  /* Initializae the cache and allocate space for the library symbols.  */
+  /* Initialize the cache and allocate space for the library symbols.  */
   ardata->cache = 0;
   amt = ardata->symdef_count;
   amt *= sizeof (carsym);
index 368aa88..537ddaa 100644 (file)
--- a/bfd/som.h
+++ b/bfd/som.h
@@ -210,7 +210,7 @@ struct som_section_data_struct
    should be internal to the BFD backend.
 
    The idea is both SOM and ELF define these basic relocation
-   types so they map into a SOM or ELF specific reloation as
+   types so they map into a SOM or ELF specific relocation as
    appropriate.  This allows GAS to share much more code
    between the two object formats.  */
 
index 0a936b1..ecaaa0f 100644 (file)
@@ -113,7 +113,7 @@ sparclinux_write_object_contents (abfd)
 #endif
 
 /* This special symbol is a set vector that contains a list of
-   pointers to fixup tables.  It will be present in any dynamicly
+   pointers to fixup tables.  It will be present in any dynamically
    linked file.  The linker generated fixup table should also be added
    to the list, and it should always appear in the second slot (the
    first one is a dummy with a magic number that is defined in
index 62e4300..c0a3d58 100644 (file)
@@ -1009,7 +1009,7 @@ srec_write_header (abfd)
 {
   unsigned int len = strlen (abfd->filename);
 
/* I'll put an arbitary 40 char limit on header size.  */
   if (len > 40)
     len = 40;
 
index 62acf12..c07f48b 100644 (file)
@@ -133,9 +133,9 @@ SUBSECTION
 |      nm foo
 |      00012345 A dummy_symbol
 
-       Many formats cannot represent arbitary symbol information; for
+       Many formats cannot represent arbitrary symbol information; for
        instance, the <<a.out>> object format does not allow an
-       arbitary number of sections. A symbol pointing to a section
+       arbitrary number of sections. A symbol pointing to a section
        which is not one  of <<.text>>, <<.data>> or <<.bss>> cannot
        be described.
 
@@ -222,7 +222,7 @@ CODE_FRAGMENT
 .     <<BSF_LOCAL>>, <<BSF_FORT_COMM>>,  <<BSF_UNDEFINED>> or
 .     <<BSF_GLOBAL>>.  *}
 .
-.  {* The symbol is a debugging record. The value has an arbitary
+.  {* The symbol is a debugging record. The value has an arbitrary
 .     meaning, unless BSF_DEBUGGING_RELOC is also set.  *}
 .#define BSF_DEBUGGING 0x08
 .
@@ -1222,7 +1222,7 @@ _bfd_stab_section_find_nearest_line (bfd *abfd,
       long low, high;
       long mid = -1;
 
-      /* Cache non-existant or invalid.  Do binary search on
+      /* Cache non-existent or invalid.  Do binary search on
          indextable.  */
       indexentry = NULL;
 
index a173857..488e8e4 100644 (file)
@@ -30,7 +30,7 @@ SECTION
        Targets
 
 DESCRIPTION
-       Each port of BFD to a different machine requries the creation
+       Each port of BFD to a different machine requires the creation
        of a target back end. All the back end provides to the root
        part of BFD is a structure containing pointers to functions
        which perform certain low level operations on files. BFD
index 32c3d97..f828fe7 100644 (file)
@@ -29,7 +29,7 @@ DESCRIPTION
        relocations. Their main application is communication with
        devices like PROM programmers and ICE equipment.
 
-       It seems that the sections are descibed as being really big,
+       It seems that the sections are described as being really big,
         the example I have says that the text section is 0..ffffffff.
        BFD would barf with this, many apps would try to alloc 4GB to
        read in the file.
index b978312..19df300 100644 (file)
@@ -32,9 +32,9 @@
 
    A VERSAdos file looks like contains
 
-   o Indentification Record
+   o Identification Record
    o External Symbol Definition Record
-   o Object Text Recrod
+   o Object Text Record
    o End Record
 
  */
index 7bb7a77..660c06c 100644 (file)
@@ -788,7 +788,7 @@ _bfd_vms_write_gsd (abfd, objtype)
          last_index++;
        }
 
-      /* Don't know if this is neccesary for the linker but for now it keeps
+      /* Don't know if this is necessary for the linker but for now it keeps
         vms_slurp_gsd happy  */
 
       sname = (char *)section->name;
index adbecac..c261111 100644 (file)
@@ -206,7 +206,7 @@ _bfd_vms_slurp_hdr (abfd, objtype)
 /*-----------------------------------------------------------------------------*/
 /* Output routines.  */
 
-/* Manufacure a VMS like time on a unix based system.
+/* Manufacture a VMS like time on a unix based system.
    stolen from obj-vms.c  */
 
 static unsigned char *
index b6f3042..d0a24c7 100644 (file)
@@ -49,7 +49,7 @@ static asymbol *new_symbol PARAMS ((bfd *, char *));
    ...
    9   almost everything
 
-   level is also identation level. Indentation is performed
+   level is also indentation level. Indentation is performed
    if level > 0
        */
 
@@ -668,7 +668,7 @@ _bfd_vms_output_begin (abfd, rectype, rechead)
 
   _bfd_vms_output_short (abfd, (unsigned int) rectype);
 
-  /* save current output position to fill in lenght later  */
+  /* save current output position to fill in length later  */
 
   if (PRIV (push_level) > 0)
     PRIV (length_pos) = PRIV (output_size);
index 6f94029..d457aa0 100644 (file)
@@ -1248,7 +1248,7 @@ xcoff_link_add_symbols (abfd, info)
                }
              linoff = (auxlin.x_sym.x_fcnary.x_fcn.x_lnnoptr
                        - enclosing->line_filepos);
-             /* explict cast to bfd_signed_vma for compiler */
+             /* explicit cast to bfd_signed_vma for compiler */
              if (linoff < (bfd_signed_vma) (enclosing->lineno_count * linesz))
                {
                  struct internal_lineno lin;
@@ -2898,7 +2898,7 @@ bfd_xcoff_size_dynamic_sections (output_bfd, info, libpath, entry,
       xcoff_mark_symbol (info, hsym);
       hsym->flags |= (XCOFF_DEF_REGULAR | XCOFF_RTINIT);
 
-      /* __rtinit initalized */
+      /* __rtinit initialized */
       amt = sizeof (struct internal_ldsym);
       ldsym = (struct internal_ldsym *) bfd_malloc (amt);
 
index 6c2e97c..7b36467 100644 (file)
@@ -133,7 +133,7 @@ typedef struct bfd_sym_resources_table_entry bfd_sym_resources_table_entry;
    (Note that having a single module copied into two resources is not
    possible).  Modules map back to their resource via an index into the
    resource table and an offset into the resource.  Modules also point
-   to their source files, both the definition module and implemention
+   to their source files, both the definition module and implementation
    module.  Because modules can be textually nested within other
    modules, a link to the parent (containing) module is required.  This
    module can textually contain other modules.  A link to the contiguous
@@ -1009,7 +1009,7 @@ srec_write_header (abfd)
   unsigned int len = strlen (abfd->filename);
 
-  /* I'll put an arbitary 40 char limit on header size.  */
+  /* I'll put an arbitrary 40 char limit on header size.  */
   if (len > 40)
     len = 40;